Find the d that when used in all dimensions give the desired D
value. It use the optimize function using several d values and
minimizing the difference with the desired D.
Find the d that when used in all dimensions give the desired D
value. It use the optimize function using several d values and
minimizing the difference with the desired D.