Calculate the multivariate D based on the Mahalanobis distance as described in Del-Giudice2009-wn. This can be interpret as the
distance between the clusters on the n-dimensional space where n is the number of indicators.
Arguments
- d
the vector of effect sizes. If length(d) is 1, the value is used for each dimension (indicator).
- Sigma
the variance-covariance matrix
Value
the Mahalanobis distance
Examples
S <- gen_sigma(4, 0.7)
multiD(c(0.4, -0.3, 0.5, 0), S)
#> [1] 1.181397